@@ -3,7 +3,7 @@
 module Clusters
   module Applications
     class Runner < ApplicationRecord
-      VERSION = '0.4.1'.freeze
+      VERSION = '0.7.0'.freeze
 
       self.table_name = 'clusters_applications_runners'
 
@@ -29,13 +29,6 @@ module Clusters
         content_values.to_yaml
       end
 
-      # Need to investigate if pipelines run by this runner will stop upon the
-      # executor pod stopping
-      # I.e.run a pipeline, and uninstall runner while pipeline is running
-      def allowed_to_uninstall?
-        false
-      end
-
       def install_command
         Gitlab::Kubernetes::Helm::InstallCommand.new(
           name: name,
@@ -47,6 +40,14 @@ module Clusters
         )
       end
 
+      def prepare_uninstall
+        runner&.update!(active: false)
+      end
+
+      def post_uninstall
+        runner.destroy!
+      end
+
       private
 
       def ensure_runner
