@@ -3,10 +3,11 @@
 class List < ApplicationRecord
   belongs_to :board
   belongs_to :label
+  include Importable
 
   enum list_type: { backlog: 0, label: 1, closed: 2, assignee: 3, milestone: 4 }
 
-  validates :board, :list_type, presence: true
+  validates :board, :list_type, presence: true, unless: :importing?
   validates :label, :position, presence: true, if: :label?
   validates :label_id, uniqueness: { scope: :board_id }, if: :label?
   validates :position, numericality: { only_integer: true, greater_than_or_equal_to: 0 }, if: :movable?
@@ -16,6 +17,7 @@ class List < ApplicationRecord
   scope :destroyable, -> { where(list_type: list_types.slice(*destroyable_types).values) }
   scope :movable, -> { where(list_type: list_types.slice(*movable_types).values) }
   scope :preload_associations, -> { preload(:board, :label) }
+  scope :ordered, -> { order(:list_type, :position) }
 
   class << self
     def destroyable_types
