@@ -6,7 +6,9 @@ class Repository
   REF_MERGE_REQUEST = 'merge-requests'.freeze
   REF_KEEP_AROUND = 'keep-around'.freeze
   REF_ENVIRONMENTS = 'environments'.freeze
-  MAX_DIVERGING_COUNT = 1000
+
+  ARCHIVE_CACHE_TIME = 60 # Cache archives referred to by a (mutable) ref for 1 minute
+  ARCHIVE_CACHE_TIME_IMMUTABLE = 3600 # Cache archives referred to by an immutable reference for 1 hour
 
   RESERVED_REFS_NAMES = %W[
     heads
@@ -274,7 +276,7 @@ class Repository
       # This will still fail if the file is corrupted (e.g. 0 bytes)
       raw_repository.write_ref(keep_around_ref_name(sha), sha)
     rescue Gitlab::Git::CommandError => ex
-      Rails.logger.error "Unable to create keep-around reference for repository #{disk_path}: #{ex}"
+      Rails.logger.error "Unable to create keep-around reference for repository #{disk_path}: #{ex}" # rubocop:disable Gitlab/RailsLogger
     end
   end
 
@@ -282,46 +284,6 @@ class Repository
     ref_exists?(keep_around_ref_name(sha))
   end
 
-  def diverging_commit_counts(branch)
-    return diverging_commit_counts_without_max(branch) if Feature.enabled?('gitaly_count_diverging_commits_no_max')
-
-    ## TODO: deprecate the below code after 12.0
-    @root_ref_hash ||= raw_repository.commit(root_ref).id
-    cache.fetch(:"diverging_commit_counts_#{branch.name}") do
-      # Rugged seems to throw a `ReferenceError` when given branch_names rather
-      # than SHA-1 hashes
-      branch_sha = branch.dereferenced_target.sha
-
-      number_commits_behind, number_commits_ahead =
-        raw_repository.diverging_commit_count(
-          @root_ref_hash,
-          branch_sha,
-          max_count: MAX_DIVERGING_COUNT)
-
-      if number_commits_behind + number_commits_ahead >= MAX_DIVERGING_COUNT
-        { distance: MAX_DIVERGING_COUNT }
-      else
-        { behind: number_commits_behind, ahead: number_commits_ahead }
-      end
-    end
-  end
-
-  def diverging_commit_counts_without_max(branch)
-    @root_ref_hash ||= raw_repository.commit(root_ref).id
-    cache.fetch(:"diverging_commit_counts_without_max_#{branch.name}") do
-      # Rugged seems to throw a `ReferenceError` when given branch_names rather
-      # than SHA-1 hashes
-      branch_sha = branch.dereferenced_target.sha
-
-      number_commits_behind, number_commits_ahead =
-        raw_repository.diverging_commit_count(
-          @root_ref_hash,
-          branch_sha)
-
-      { behind: number_commits_behind, ahead: number_commits_ahead }
-    end
-  end
-
   def archive_metadata(ref, storage_path, format = "tar.gz", append_sha:, path: nil)
     raw_repository.archive_metadata(
       ref,
@@ -427,11 +389,15 @@ class Repository
     expire_statistics_caches
   end
 
-  # Runs code after a repository has been created.
-  def after_create
+  def expire_status_cache
     expire_exists_cache
     expire_root_ref_cache
     expire_emptiness_caches
+  end
+
+  # Runs code after a repository has been created.
+  def after_create
+    expire_status_cache
 
     repository_event(:create_repository)
   end
@@ -456,25 +422,29 @@ class Repository
   end
 
   # Runs code before pushing (= creating or removing) a tag.
+  #
+  # Note that this doesn't expire the tags. You may need to call
+  # expire_caches_for_tags or expire_tags_cache.
   def before_push_tag
+    repository_event(:push_tag)
+  end
+
+  def expire_caches_for_tags
     expire_statistics_caches
     expire_emptiness_caches
     expire_tags_cache
-
-    repository_event(:push_tag)
   end
 
   # Runs code before removing a tag.
   def before_remove_tag
-    expire_tags_cache
-    expire_statistics_caches
+    expire_caches_for_tags
 
     repository_event(:remove_tag)
   end
 
   # Runs code after removing a tag.
   def after_remove_tag
-    expire_tags_cache
+    expire_caches_for_tags
   end
 
   # Runs code after the HEAD of a repository is changed.
@@ -498,8 +468,8 @@ class Repository
   end
 
   # Runs code after a new branch has been created.
-  def after_create_branch
-    expire_branches_cache
+  def after_create_branch(expire_cache: true)
+    expire_branches_cache if expire_cache
 
     repository_event(:push_branch)
   end
@@ -512,8 +482,8 @@ class Repository
   end
 
   # Runs code after an existing branch has been removed.
-  def after_remove_branch
-    expire_branches_cache
+  def after_remove_branch(expire_cache: true)
+    expire_branches_cache if expire_cache
   end
 
   def method_missing(msg, *args, &block)
@@ -880,10 +850,14 @@ class Repository
     end
   end
 
-  def merge_to_ref(user, source_sha, merge_request, target_ref, message)
+  def merge_to_ref(user, source_sha, merge_request, target_ref, message, first_parent_ref)
     branch = merge_request.target_branch
 
-    raw.merge_to_ref(user, source_sha, branch, target_ref, message)
+    raw.merge_to_ref(user, source_sha, branch, target_ref, message, first_parent_ref)
+  end
+
+  def delete_refs(*ref_names)
+    raw.delete_refs(*ref_names)
   end
 
   def ff_merge(user, source, target_branch, merge_request: nil)
@@ -971,6 +945,7 @@ class Repository
     async_remove_remote(remote_name) if tmp_remote_name
   end
 
+  # rubocop:disable Gitlab/RailsLogger
   def async_remove_remote(remote_name)
     return unless remote_name
 
@@ -984,6 +959,7 @@ class Repository
 
     job_id
   end
+  # rubocop:enable Gitlab/RailsLogger
 
   def fetch_source_branch!(source_repository, source_branch, local_ref)
     raw_repository.fetch_source_branch!(source_repository.raw_repository, source_branch, local_ref)
