@@ -25,7 +25,7 @@ module SystemNoteService
 
     text_parts = ["added #{commits_text}"]
     text_parts << commits_list(noteable, new_commits, existing_commits, oldrev)
-    text_parts << "[Compare with previous version](#{diff_comparison_url(noteable, project, oldrev)})"
+    text_parts << "[Compare with previous version](#{diff_comparison_path(noteable, project, oldrev)})"
 
     body = text_parts.join("\n\n")
 
@@ -41,7 +41,7 @@ module SystemNoteService
   #
   # Returns the created Note object
   def tag_commit(noteable, project, author, tag_name)
-    link = url_helpers.project_tag_url(project, id: tag_name)
+    link = url_helpers.project_tag_path(project, id: tag_name)
     body = "tagged commit #{noteable.sha} to [`#{tag_name}`](#{link})"
 
     create_note(NoteSummary.new(noteable, project, author, body, action: 'tag'))
@@ -221,8 +221,8 @@ module SystemNoteService
   end
 
   # Called when 'merge when pipeline succeeds' is executed
-  def merge_when_pipeline_succeeds(noteable, project, author, last_commit)
-    body = "enabled an automatic merge when the pipeline for #{last_commit.to_reference(project)} succeeds"
+  def merge_when_pipeline_succeeds(noteable, project, author, sha)
+    body = "enabled an automatic merge when the pipeline for #{sha} succeeds"
 
     create_note(NoteSummary.new(noteable, project, author, body, action: 'merge'))
   end
@@ -234,6 +234,16 @@ module SystemNoteService
     create_note(NoteSummary.new(noteable, project, author, body, action: 'merge'))
   end
 
+  # Called when 'merge when pipeline succeeds' is aborted
+  def abort_merge_when_pipeline_succeeds(noteable, project, author, reason)
+    body = "aborted the automatic merge because #{reason}"
+
+    ##
+    # TODO: Abort message should be sent by the system, not a particular user.
+    # See https://gitlab.com/gitlab-org/gitlab-ce/issues/63187.
+    create_note(NoteSummary.new(noteable, project, author, body, action: 'merge'))
+  end
+
   def handle_merge_request_wip(noteable, project, author)
     prefix = noteable.work_in_progress? ? "marked" : "unmarked"
 
@@ -249,7 +259,7 @@ module SystemNoteService
   end
 
   def resolve_all_discussions(merge_request, project, author)
-    body = "resolved all discussions"
+    body = "resolved all threads"
 
     create_note(NoteSummary.new(merge_request, project, author, body, action: 'discussion'))
   end
@@ -268,11 +278,13 @@ module SystemNoteService
     merge_request = discussion.noteable
     diff_refs = change_position.diff_refs
     version_index = merge_request.merge_request_diffs.viewable.count
+    position_on_text = change_position.on_text?
+    text_parts = ["changed this #{position_on_text ? 'line' : 'file'} in"]
 
-    text_parts = ["changed this line in"]
     if version_params = merge_request.version_params_for(diff_refs)
-      line_code = change_position.line_code(project.repository)
-      url = url_helpers.diffs_project_merge_request_url(project, merge_request, version_params.merge(anchor: line_code))
+      repository = project.repository
+      anchor = position_on_text ? change_position.line_code(repository) : change_position.file_hash
+      url = url_helpers.diffs_project_merge_request_path(project, merge_request, version_params.merge(anchor: anchor))
 
       text_parts << "[version #{version_index} of the diff](#{url})"
     else
@@ -404,8 +416,9 @@ module SystemNoteService
   # Example note text:
   #
   #   "created branch `201-issue-branch-button`"
-  def new_issue_branch(issue, project, author, branch)
-    link = url_helpers.project_compare_url(project, from: project.default_branch, to: branch)
+  def new_issue_branch(issue, project, author, branch, branch_project: nil)
+    branch_project ||= project
+    link = url_helpers.project_compare_path(branch_project, from: branch_project.default_branch, to: branch)
 
     body = "created branch [`#{branch}`](#{link}) to address this issue"
 
@@ -413,7 +426,7 @@ module SystemNoteService
   end
 
   def new_merge_request(issue, project, author, merge_request)
-    body = "created merge request #{merge_request.to_reference} to address this issue"
+    body = "created merge request #{merge_request.to_reference(project)} to address this issue"
 
     create_note(NoteSummary.new(issue, project, author, body, action: 'merge'))
   end
@@ -584,6 +597,14 @@ module SystemNoteService
     note_text =~ /\A#{cross_reference_note_prefix}/i
   end
 
+  def zoom_link_added(issue, project, author)
+    create_note(NoteSummary.new(issue, project, author, _('a Zoom call was added to this issue'), action: 'pinned_embed'))
+  end
+
+  def zoom_link_removed(issue, project, author)
+    create_note(NoteSummary.new(issue, project, author, _('a Zoom call was removed from this issue'), action: 'pinned_embed'))
+  end
+
   private
 
   # rubocop: disable CodeReuse/ActiveRecord
@@ -668,10 +689,10 @@ module SystemNoteService
     @url_helpers ||= Gitlab::Routing.url_helpers
   end
 
-  def diff_comparison_url(merge_request, project, oldrev)
+  def diff_comparison_path(merge_request, project, oldrev)
     diff_id = merge_request.merge_request_diff.id
 
-    url_helpers.diffs_project_merge_request_url(
+    url_helpers.diffs_project_merge_request_path(
       project,
       merge_request,
       diff_id: diff_id,
