@@ -79,12 +79,22 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           resource :operations, only: [:show, :update]
           resource :integrations, only: [:show]
 
+          Gitlab.ee do
+            resource :slack, only: [:destroy, :edit, :update] do
+              get :slack_auth
+            end
+          end
+
           resource :repository, only: [:show], controller: :repository do
             post :create_deploy_token, path: 'deploy_token/create'
             post :cleanup
           end
         end
 
+        Gitlab.ee do
+          resources :feature_flags
+        end
+
         resources :autocomplete_sources, only: [] do
           collection do
             get 'members'
@@ -155,8 +165,14 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           end
         end
 
-        resources :boards, only: [:index, :show], constraints: { id: /\d+/ }
+        resources :boards, only: [:index, :show, :create, :update, :destroy], constraints: { id: /\d+/ } do
+          collection do
+            get :recent
+          end
+        end
+
         resources :releases, only: [:index]
+        resources :starrers, only: [:index]
         resources :forks, only: [:index, :new, :create]
         resources :group_links, only: [:index, :create, :update, :destroy], constraints: { id: /\d+/ }
 
@@ -202,8 +218,18 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
       resource :mattermost, only: [:new, :create]
 
       namespace :prometheus do
-        resources :metrics, constraints: { id: %r{[^\/]+} }, only: [] do
+        resources :metrics, constraints: { id: %r{[^\/]+} }, only: [:index, :new, :create, :edit, :update, :destroy] do
           get :active_common, on: :collection
+
+          Gitlab.ee do
+            post :validate_query, on: :collection
+          end
+        end
+
+        Gitlab.ee do
+          resources :alerts, constraints: { id: /\d+/ }, only: [:index, :create, :show, :update, :destroy] do
+            post :notify, on: :collection
+          end
         end
       end
 
@@ -215,6 +241,15 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           get :pipeline_status
           get :ci_environments_status
           post :toggle_subscription
+
+          Gitlab.ee do
+            get :approvals
+            post :approvals, action: :approve
+            delete :approvals, action: :unapprove
+
+            post :rebase
+          end
+
           post :remove_wip
           post :assign_related_issues
           get :discussions, format: :json
@@ -231,6 +266,8 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
             get :commits
             get :pipelines
             get :diffs, to: 'merge_requests/diffs#show'
+            get :widget, to: 'merge_requests/content#widget'
+            get :cached_widget, to: 'merge_requests/content#cached_widget'
           end
 
           get :diff_for_path, controller: 'merge_requests/diffs'
@@ -247,6 +284,21 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           post :bulk_update
         end
 
+        Gitlab.ee do
+          resources :approvers, only: :destroy
+          delete 'approvers', to: 'approvers#destroy_via_user_id', as: :approver_via_user_id
+          resources :approver_groups, only: :destroy
+
+          scope module: :merge_requests do
+            resources :drafts, only: [:index, :update, :create, :destroy] do
+              collection do
+                post :publish
+                delete :discard
+              end
+            end
+          end
+        end
+
         resources :discussions, only: [:show], constraints: { id: /\h{40}/ } do
           member do
             post :resolve
@@ -277,13 +329,20 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         end
       end
 
+      Gitlab.ee do
+        resources :path_locks, only: [:index, :destroy] do
+          collection do
+            post :toggle
+          end
+        end
+
+        get '/service_desk' => 'service_desk#show', as: :service_desk
+        put '/service_desk' => 'service_desk#update', as: :service_desk_refresh
+      end
+
       resource :variables, only: [:show, :update]
 
-      resources :triggers, only: [:index, :create, :edit, :update, :destroy] do
-        member do
-          post :take_ownership
-        end
-      end
+      resources :triggers, only: [:index, :create, :edit, :update, :destroy]
 
       resource :mirror, only: [:show, :update] do
         member do
@@ -292,6 +351,10 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         end
       end
 
+      Gitlab.ee do
+        resources :push_rules, constraints: { id: /\d+/ }, only: [:update]
+      end
+
       resources :pipelines, only: [:index, :new, :create, :show] do
         collection do
           resource :pipelines_settings, path: 'settings', only: [:show, :update]
@@ -306,6 +369,11 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           get :builds
           get :failures
           get :status
+
+          Gitlab.ee do
+            get :security
+            get :licenses
+          end
         end
 
         member do
@@ -334,6 +402,10 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           get '/terminal.ws/authorize', to: 'environments#terminal_websocket_authorize', constraints: { format: nil }
 
           get '/prometheus/api/v1/*proxy_path', to: 'environments/prometheus_api#proxy', as: :prometheus_api
+
+          Gitlab.ee do
+            get :logs
+          end
         end
 
         collection do
@@ -350,6 +422,14 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         end
       end
 
+      Gitlab.ee do
+        resources :protected_environments, only: [:create, :update, :destroy], constraints: { id: /\d+/ } do
+          collection do
+            get 'search'
+          end
+        end
+      end
+
       resource :cycle_analytics, only: [:show]
 
       namespace :cycle_analytics do
@@ -397,11 +477,23 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           # in JSON format, or a request for tag named `latest.json`.
           scope format: false do
             resources :tags, only: [:index, :destroy],
-                             constraints: { id: Gitlab::Regex.container_registry_tag_regex }
+                             constraints: { id: Gitlab::Regex.container_registry_tag_regex } do
+              collection do
+                delete :bulk_destroy
+              end
+            end
           end
         end
       end
 
+      Gitlab.ee do
+        namespace :security do
+          resource :dashboard, only: [:show], controller: :dashboard
+        end
+
+        resources :vulnerability_feedback, only: [:index, :create, :update, :destroy], constraints: { id: /\d+/ }
+      end
+
       get :issues, to: 'issues#calendar', constraints: lambda { |req| req.format == :ics }
 
       resources :issues, concerns: :awardable, constraints: { id: /\d+/ } do
@@ -409,16 +501,30 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           post :toggle_subscription
           post :mark_as_spam
           post :move
+          put :reorder
           get :related_branches
           get :can_create_branch
           get :realtime_changes
           post :create_merge_request
           get :discussions, format: :json
+
+          Gitlab.ee do
+            get 'designs(/*vueroute)', to: 'issues#show', as: :designs, format: false
+          end
         end
 
         collection do
           post :bulk_update
           post :import_csv
+
+          Gitlab.ee do
+            post :export_csv
+            get :service_desk
+          end
+        end
+
+        Gitlab.ee do
+          resources :issue_links, only: [:index, :create, :destroy], as: 'links', path: 'links'
         end
       end
 
@@ -453,6 +559,11 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         end
       end
 
+      Gitlab.ee do
+        resources :approvers, only: :destroy
+        resources :approver_groups, only: :destroy
+      end
+
       resources :runner_projects, only: [:create, :destroy]
       resources :badges, only: [:index] do
         collection do
@@ -467,6 +578,10 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         end
       end
 
+      Gitlab.ee do
+        resources :audit_events, only: [:index]
+      end
+
       resources :error_tracking, only: [:index], controller: :error_tracking do
         collection do
           post :list_projects
@@ -477,6 +592,10 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
       # its preferable to keep it below all other project routes
       draw :wiki
       draw :repository
+
+      Gitlab.ee do
+        resources :managed_licenses, only: [:index, :show, :new, :create, :edit, :update, :destroy]
+      end
     end
 
     resources(:projects,
