@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 puts "Creating the default ApplicationSetting record.".color(:green)
-Gitlab::CurrentSettings.current_application_settings
+ApplicationSetting.create_from_defaults
 
 # Details https://gitlab.com/gitlab-org/gitlab-ce/issues/46241
 puts "Enable hashed storage for every new projects.".color(:green)
