@@ -3,6 +3,20 @@
 module ExpandVariables
   class << self
     def expand(value, variables)
+      variables_hash = nil
+
+      value.gsub(/\$([a-zA-Z_][a-zA-Z0-9_]*)|\${\g<1>}|%\g<1>%/) do
+        variables_hash ||= transform_variables(variables)
+        variables_hash[$1 || $2]
+      end
+    end
+
+    private
+
+    def transform_variables(variables)
+      # Lazily initialise variables
+      variables = variables.call if variables.is_a?(Proc)
+
       # Convert hash array to variables
       if variables.is_a?(Array)
         variables = variables.reduce({}) do |hash, variable|
@@ -11,9 +25,7 @@ module ExpandVariables
         end
       end
 
-      value.gsub(/\$([a-zA-Z_][a-zA-Z0-9_]*)|\${\g<1>}|%\g<1>%/) do
-        variables[$1 || $2]
-      end
+      variables
     end
   end
 end
