@@ -4,7 +4,14 @@ module Gitlab
   class PushOptions
     VALID_OPTIONS = HashWithIndifferentAccess.new({
       merge_request: {
-        keys: [:create, :merge_when_pipeline_succeeds, :target]
+        keys: [
+          :create,
+          :description,
+          :merge_when_pipeline_succeeds,
+          :remove_source_branch,
+          :target,
+          :title
+        ]
       },
       ci: {
         keys: [:skip]
