@@ -66,6 +66,35 @@ module Gitlab
           @explanation = block_given? ? block : text
         end
 
+        # Allows to provide a message about quick action execution result, success or failure.
+        # This message is shown after quick action execution and after saving the note.
+        #
+        # Example:
+        #
+        #   execution_message do |arguments|
+        #     "Added label(s) #{arguments.join(' ')}"
+        #   end
+        #   command :command_key do |arguments|
+        #     # Awesome code block
+        #   end
+        #
+        # Note: The execution_message won't be executed unless the condition block returns true.
+        #       execution_message block is executed always after the command block has run,
+        #       for this reason if the condition block doesn't return true after the command block has
+        #       run you need to set the @execution_message variable inside the command block instead as
+        #       shown in the following example.
+        #
+        # Example using instance variable:
+        #
+        #   command :command_key do |arguments|
+        #     # Awesome code block
+        #     @execution_message[:command_key] = 'command_key executed successfully'
+        #   end
+        #
+        def execution_message(text = '', &block)
+          @execution_message = block_given? ? block : text
+        end
+
         # Allows to define type(s) that must be met in order for the command
         # to be returned by `.command_names` & `.command_definitions`.
         #
@@ -121,10 +150,16 @@ module Gitlab
         # comment.
         # It accepts aliases and takes a block.
         #
+        # You can also set the @execution_message instance variable, on conflicts with
+        # execution_message method the instance variable has precedence.
+        #
         # Example:
         #
         #   command :my_command, :alias_for_my_command do |arguments|
         #     # Awesome code block
+        #     @updates[:my_command] = 'foo'
+        #
+        #     @execution_message[:my_command] = 'my_command executed successfully'
         #   end
         def command(*command_names, &block)
           define_command(CommandDefinition, *command_names, &block)
@@ -158,6 +193,7 @@ module Gitlab
             description: @description,
             warning: @warning,
             explanation: @explanation,
+            execution_message: @execution_message,
             params: @params,
             condition_block: @condition_block,
             parse_params_block: @parse_params_block,
@@ -173,6 +209,7 @@ module Gitlab
 
           @description = nil
           @explanation = nil
+          @execution_message = nil
           @params = nil
           @condition_block = nil
           @warning = nil
