@@ -6,7 +6,9 @@ module Gitlab
 
     class << self
       def data(force_refresh: false)
-        Rails.cache.fetch('usage_data', force: force_refresh, expires_in: 2.weeks) { uncached_data }
+        Rails.cache.fetch('usage_data', force: force_refresh, expires_in: 2.weeks) do
+          uncached_data
+        end
       end
 
       def uncached_data
@@ -26,7 +28,7 @@ module Gitlab
           uuid: Gitlab::CurrentSettings.uuid,
           hostname: Gitlab.config.gitlab.host,
           version: Gitlab::VERSION,
-          installation_type: Gitlab::INSTALLATION_TYPE,
+          installation_type: installation_type,
           active_user_count: count(User.active),
           recorded_at: Time.now,
           edition: 'CE'
@@ -81,6 +83,7 @@ module Gitlab
             milestone_lists: count(List.milestone),
             milestones: count(Milestone),
             pages_domains: count(PagesDomain),
+            pool_repositories: count(PoolRepository),
             projects: count(Project),
             projects_imported_from_github: count(Project.where(import_type: 'github')),
             projects_with_repositories_enabled: count(ProjectFeature.where('repository_access_level > ?', ProjectFeature::DISABLED)),
@@ -97,9 +100,7 @@ module Gitlab
           .merge(services_usage)
           .merge(approximate_counts)
         }.tap do |data|
-          if Feature.enabled?(:group_overview_security_dashboard)
-            data[:counts][:user_preferences] = user_preferences_usage
-          end
+          data[:counts][:user_preferences] = user_preferences_usage
         end
       end
       # rubocop: enable CodeReuse/ActiveRecord
@@ -127,16 +128,29 @@ module Gitlab
         }
       end
 
+      # @return [Hash<Symbol, Integer>]
       def usage_counters
-        {
-          web_ide_commits: Gitlab::WebIdeCommitsCounter.total_count
-        }
+        usage_data_counters.map(&:totals).reduce({}) { |a, b| a.merge(b) }
+      end
+
+      # @return [Array<#totals>] An array of objects that respond to `#totals`
+      def usage_data_counters
+        [
+         Gitlab::UsageDataCounters::WikiPageCounter,
+         Gitlab::UsageDataCounters::WebIdeCounter,
+         Gitlab::UsageDataCounters::NoteCounter,
+         Gitlab::UsageDataCounters::SnippetCounter,
+         Gitlab::UsageDataCounters::SearchCounter,
+         Gitlab::UsageDataCounters::CycleAnalyticsCounter,
+         Gitlab::UsageDataCounters::SourceCodeCounter
+        ]
       end
 
       def components_usage_data
         {
-          gitlab_pages: { enabled: Gitlab.config.pages.enabled, version: Gitlab::Pages::VERSION },
           git: { version: Gitlab::Git.version },
+          gitaly: { version: Gitaly::Server.all.first.server_version, servers: Gitaly::Server.count, filesystems: Gitaly::Server.filesystems },
+          gitlab_pages: { enabled: Gitlab.config.pages.enabled, version: Gitlab::Pages::VERSION },
           database: { adapter: Gitlab::Database.adapter_name, version: Gitlab::Database.version }
         }
       end
@@ -190,6 +204,14 @@ module Gitlab
           result[key] = approx_counts[model] || -1
         end
       end
+
+      def installation_type
+        if Rails.env.production?
+          Gitlab::INSTALLATION_TYPE
+        else
+          "gitlab-development-kit"
+        end
+      end
     end
   end
 end
